@@ -8,7 +8,7 @@ use HTTP::Tiny;
 use strict;
 use warnings;
 
-our $VERSION = '1.11';
+our $VERSION = '1.12';
 $VERSION = eval $VERSION;
 
 sub new {
@@ -215,11 +215,11 @@ __END__
 
 =head1 NAME
 
-L<Business::Stripe::Webhook> - A Perl module for handling webhooks sent by Stripe
+Business::Stripe::Webhook - A Perl module for handling webhooks sent by Stripe
 
 =head1 VERSION
 
-Version 1.10
+Version 1.12
 
 =head1 SYNOPSIS
 
@@ -246,12 +246,12 @@ Version 1.10
       $webhook->reply(error => $webhook->error());
   }
   
-  sub invoice-paid {
+  sub update_invoice {
       # Process paid invoice
       ...
   }
   
-  sub checkout-session-completed {
+  sub update_session {
       # Process checkout
       ...
   }
